==============
barbell2light
==============


.. image:: https://img.shields.io/pypi/v/barbell2light.svg
        :target: https://pypi.python.org/pypi/barbell2light

.. image:: https://img.shields.io/travis/rbrecheisen/barbell2light.svg
        :target: https://travis-ci.com/rbrecheisen/barbell2light

.. image:: https://readthedocs.org/projects/barbell2light/badge/?version=latest
        :target: https://barbell2light.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: MIT license
* Documentation: https://barbell2light.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
